@@ -7,13 +7,16 @@ django_sudo.utils
 """
 from django.utils.crypto import get_random_string
 
-from django_sudo import COOKIE_NAME, COOKIE_MAX_AGE
+from django_sudo.settings import COOKIE_NAME, COOKIE_AGE
 
 
-def grant_sudo_privileges(request, max_age=COOKIE_MAX_AGE):
+def grant_sudo_privileges(request, max_age=COOKIE_AGE):
     """
-    Assigns a random token to the user's session that allows them to have elevated permissions
+    Assigns a random token to the user's session
+    that allows them to have elevated permissions
     """
+    if not request.user.is_authenticated():
+        raise ValueError('User needs to be logged in to be elevated to sudo')
     # Token doesn't need to be unique,
     # just needs to be unpredictable and match the cookie and the session
     token = get_random_string()
